==> icinga2_2.3.2.orig.tar.gz: icinga2-2.3.2/lib/livestatus/minaggregator.hpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2015 Icinga Development Team (http://www.icinga.org)    *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#ifndef MINAGGREGATOR_H
#define MINAGGREGATOR_H

#include "livestatus/table.hpp"
#include "livestatus/aggregator.hpp"

namespace icinga
{

/**
 * @ingroup livestatus
 */
class I2_LIVESTATUS_API MinAggregator : public Aggregator
{
public:
	DECLARE_PTR_TYPEDEFS(MinAggregator);

	MinAggregator(const String& attr);

	virtual void Apply(const Table::Ptr& table, const Value& row);
	virtual double GetResult(void) const;

private:
	double m_Min;
	String m_MinAttr;
};

}

#endif /* MINAGGREGATOR_H */

==> icinga2_2.6.3.orig.tar.gz: icinga2-2.6.3/lib/livestatus/minaggregator.hpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#ifndef MINAGGREGATOR_H
#define MINAGGREGATOR_H

#include "livestatus/table.hpp"
#include "livestatus/aggregator.hpp"

namespace icinga
{

/**
 * @ingroup livestatus
 */
class I2_LIVESTATUS_API MinAggregator : public Aggregator
{
public:
	DECLARE_PTR_TYPEDEFS(MinAggregator);

	MinAggregator(const String& attr);

	virtual void Apply(const Table::Ptr& table, const Value& row) override;
	virtual double GetResult(void) const override;

private:
	double m_Min;
	String m_MinAttr;
};

}

#endif /* MINAGGREGATOR_H */
